# 1C discharge from full

Discharge lithium-ion battery from full charge at 1C, using the initial conditions from the paper

> Kieran O’Regan, Ferran Brosa Planella, W. Dhammika Widanage, and Emma Kendrick. ["Thermal-electrochemical parametrisation of a lithium-ion battery: mapping Li concentration and temperature dependencies."]() Journal of the Electrochemical Society, submitted (2021)

and references therein.
